@@ -1,3 +1,4 @@
+"""Internally used rule classes."""
 import logging
 from typing import TYPE_CHECKING, Any, Dict, List, Union
 
@@ -9,19 +10,41 @@ if TYPE_CHECKING:
     from ansiblelint.file_utils import Lintable
 
 _logger = logging.getLogger(__name__)
+LOAD_FAILURE_MD = """\
+## load-failure
+
+Linter failed to process a YAML file, probably because it is either:
+
+* contains unsupported encoding (only UTF-8 is supported)
+* not an Ansible file
+* it contains some unsupported custom YAML objects (`!!` prefix)
+* it was not able to decrypt an inline `!vault` block.
+
+This violation **is not** skippable, so it cannot be added to the `warn_list`
+or the `skip_list`. If a vault decryption issue cannot be avoided, the
+offending file can be added to `exclude_paths` configuration.
+"""
 
 
+# Derived rules are likely to want to access class members, so:
+# pylint: disable=unused-argument
 class BaseRule:
     """Root class used by Rules."""
 
     id: str = ""
     tags: List[str] = []
-    shortdesc: str = ""
     description: str = ""
+    help: str = ""  # markdown help (automatically loaded from `<rule>.md`)
     version_added: str = ""
     severity: str = ""
     link: str = ""
     has_dynamic_tags: bool = False
+    needs_raw_task: bool = False
+
+    @property
+    def shortdesc(self) -> str:
+        """Return the short description of the rule, basically the docstring."""
+        return self.__doc__ or ""
 
     def getmatches(self, file: "Lintable") -> List["MatchError"]:
         """Return all matches while ignoring exceptions."""
@@ -30,12 +53,12 @@ class BaseRule:
             for method in [self.matchlines, self.matchtasks, self.matchyaml]:
                 try:
                     matches.extend(method(file))
-                except Exception as e:
+                except Exception as exc:  # pylint: disable=broad-except
                     _logger.debug(
                         "Ignored exception from %s.%s: %s",
                         self.__class__.__name__,
                         method,
-                        e,
+                        exc,
                     )
         else:
             matches.extend(self.matchdir(file))
@@ -48,7 +71,12 @@ class BaseRule:
     def matchtask(
         self, task: Dict[str, Any], file: "Optional[Lintable]" = None
     ) -> Union[bool, str]:
-        """Confirm if current rule is matching a specific task."""
+        """Confirm if current rule is matching a specific task.
+
+        If ``needs_raw_task`` (a class level attribute) is ``True``, then
+        the original task (before normalization) will be made available under
+        ``task["__raw_task__"]``.
+        """
         return False
 
     def matchtasks(self, file: "Lintable") -> List["MatchError"]:
@@ -82,39 +110,40 @@ class BaseRule:
         return self.id < other.id
 
 
-class RuntimeErrorRule(BaseRule):
-    """Used to identify errors."""
+# pylint: enable=unused-argument
 
-    id = 'internal-error'
-    shortdesc = 'Unexpected internal error'
+
+class RuntimeErrorRule(BaseRule):
+    """Unexpected internal error."""
+
+    id = "internal-error"
     description = (
-        'This error can be caused by internal bugs but also by '
-        'custom rules. Instead of just stopping linter we generate the errors and '
-        'continue processing. This allows users to add this rule to their warn list until '
-        'the root cause is fixed.'
+        "This error can be caused by internal bugs but also by "
+        "custom rules. Instead of just stopping linter we generate the errors and "
+        "continue processing. This allows users to add this rule to their warn list until "
+        "the root cause is fixed."
     )
-    severity = 'VERY_HIGH'
-    tags = ['core']
-    version_added = 'v5.0.0'
+    severity = "VERY_HIGH"
+    tags = ["core"]
+    version_added = "v5.0.0"
 
 
 class AnsibleParserErrorRule(BaseRule):
-    """Used to mark errors received from Ansible."""
+    """AnsibleParserError."""
 
-    id = 'parser-error'
-    shortdesc = 'AnsibleParserError'
-    description = 'Ansible parser fails; this usually indicates an invalid file.'
-    severity = 'VERY_HIGH'
-    tags = ['core']
-    version_added = 'v5.0.0'
+    id = "parser-error"
+    description = "Ansible parser fails; this usually indicates an invalid file."
+    severity = "VERY_HIGH"
+    tags = ["core"]
+    version_added = "v5.0.0"
 
 
 class LoadingFailureRule(BaseRule):
-    """File loading failure."""
+    """Failed to load or parse file."""
 
-    id = 'load-failure'
-    shortdesc = 'Failed to load or parse file'
-    description = 'Linter failed to process a YAML file, possible not an Ansible file.'
-    severity = 'VERY_HIGH'
-    tags = ['core']
-    version_added = 'v4.3.0'
+    id = "load-failure"
+    description = "Linter failed to process a YAML file, possible not an Ansible file."
+    severity = "VERY_HIGH"
+    tags = ["core", "unskippable"]
+    version_added = "v4.3.0"
+    help = LOAD_FAILURE_MD
