@@ -3,16 +3,23 @@ import os
 import re
 from argparse import Namespace
 from functools import lru_cache
+from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
 
+from ansiblelint.loaders import yaml_from_file
+
 DEFAULT_KINDS = [
     # Do not sort this list, order matters.
     {"jinja2": "**/*.j2"},  # jinja2 templates are not always parsable as something else
     {"jinja2": "**/*.j2.*"},
     {"yaml": ".github/**/*.{yaml,yml}"},  # github workflows
     {"text": "**/templates/**/*.*"},  # templates are likely not validable
-    {"inventory": "**/inventory/**.yml"},
-    {"requirements": "**/meta/requirements.yml"},  # v1 only
+    {"execution-environment": "**/execution-environment.yml"},
+    {"ansible-lint-config": "**/.ansible-lint"},
+    {"ansible-lint-config": "**/.config/ansible-lint.yml"},
+    {"ansible-navigator-config": "**/ansible-navigator.{yaml,yml}"},
+    {"inventory": "**/inventory/**.{yaml,yml}"},
+    {"requirements": "**/meta/requirements.{yaml,yml}"},  # v1 only
     # https://docs.ansible.com/ansible/latest/dev_guide/collections_galaxy_meta.html
     {"galaxy": "**/galaxy.yml"},  # Galaxy collection meta
     {"reno": "**/releasenotes/*/*.{yaml,yml}"},  # reno release notes
@@ -22,14 +29,16 @@ DEFAULT_KINDS = [
     {"tasks": "**/tasks/**/*.{yaml,yml}"},
     {"handlers": "**/handlers/*.{yaml,yml}"},
     {"vars": "**/{host_vars,group_vars,vars,defaults}/**/*.{yaml,yml}"},
+    {"test-meta": "**/tests/integration/targets/*/meta/main.{yaml,yml}"},
     {"meta": "**/meta/main.{yaml,yml}"},
-    {"arg_specs": "**/roles/**/meta/argument_specs.{yaml,yml}"},  # role argument specs
+    {"meta-runtime": "**/meta/runtime.{yaml,yml}"},
+    {"arg_specs": "**/meta/argument_specs.{yaml,yml}"},  # role argument specs
     {"yaml": ".config/molecule/config.{yaml,yml}"},  # molecule global config
     {
         "requirements": "**/molecule/*/{collections,requirements}.{yaml,yml}"
     },  # molecule old collection requirements (v1), ansible 2.8 only
     {"yaml": "**/molecule/*/{base,molecule}.{yaml,yml}"},  # molecule config
-    {"requirements": "**/requirements.yml"},  # v2 and v1
+    {"requirements": "**/requirements.{yaml,yml}"},  # v2 and v1
     {"playbook": "**/molecule/*/*.{yaml,yml}"},  # molecule playbooks
     {"yaml": "**/{.ansible-lint,.yamllint}"},
     {"yaml": "**/*.{yaml,yml}"},
@@ -59,22 +68,23 @@ BASE_KINDS = [
 # Maps kinds to JSON schemas
 # See https://www.schemastore.org/json/
 JSON_SCHEMAS = {
-    # playbook and task schemas not used yet due jsonschema bug:
-    # https://github.com/python-jsonschema/jsonschema/issues/931
-    # "playbook": "https://raw.githubusercontent.com/ansible/schemas/main/f/ansible.json#/definitions/playbook",
-    # "tasks": "https://raw.githubusercontent.com/ansible/schemas/main/f/ansible.json#/definitions/tasks",
+    # Do not use anchors in these URLs because python-jsonschema does not support them:
+    "playbook": "https://raw.githubusercontent.com/ansible/schemas/main/f/ansible-playbook.json",
+    "tasks": "https://raw.githubusercontent.com/ansible/schemas/main/f/ansible-tasks.json",
     "vars": "https://raw.githubusercontent.com/ansible/schemas/main/f/ansible-vars.json",
     "requirements": "https://raw.githubusercontent.com/ansible/schemas/main/f/ansible-requirements.json",
     "meta": "https://raw.githubusercontent.com/ansible/schemas/main/f/ansible-meta.json",
     "galaxy": "https://raw.githubusercontent.com/ansible/schemas/main/f/ansible-galaxy.json",
-    # unsupported yet:
     "execution-environment": "https://raw.githubusercontent.com/ansible/schemas/main/f/ansible-ee.json",
     "meta-runtime": "https://raw.githubusercontent.com/ansible/schemas/main/f/ansible-meta-runtime.json",
     "inventory": "https://raw.githubusercontent.com/ansible/schemas/main/f/ansible-inventory.json",
     "ansible-lint-config": "https://raw.githubusercontent.com/ansible/schemas/main/f/ansible-lint.json",
     "ansible-navigator-config": "https://raw.githubusercontent.com/ansible/ansible-navigator/main/src/ansible_navigator/data/ansible-navigator.json",
+    "arg_specs": "https://raw.githubusercontent.com/ansible/schemas/main/f/ansible-argument-specs.json",
 }
 
+PROFILES = yaml_from_file(Path(__file__).parent / "data" / "profiles.yml")
+
 options = Namespace(
     cache_dir=None,
     colored=True,
